@@ -362,8 +362,10 @@ class QuantEngineClient:
         def on_error(ws, error):
             print(error)
 
-        def on_close(ws):
+        def on_close(ws, error, msg):
             print('websockets closed')
+            print(error)
+            print(msg)
             self.stop_event.set()
 
         def on_open(ws):
